|PyPI Version| |Build Status| |Coverage Status| |Python Version|

A suite of command-line tools for working with OCDS data to:

* create release packages from releases
* create record packages from release packages
* create compiled releases and versioned releases from release packages
* upgrade from an old version of OCDS to a new version
* detect the format of a file
* combine small packages into large packages
* split large packages into small packages
* load packages into a database
* validate JSON data against a JSON schema
* generate a spreadsheet version of a JSON schema

If you are viewing this on GitHub or PyPi, open the `full documentation <https://ocdskit.readthedocs.io/>`__ for additional details.

.. |PyPI Version| image:: https://img.shields.io/pypi/v/ocdskit.svg
   :target: https://pypi.org/project/ocdskit/
.. |Build Status| image:: https://secure.travis-ci.org/open-contracting/ocdskit.png
   :target: https://travis-ci.org/open-contracting/ocdskit
.. |Coverage Status| image:: https://coveralls.io/repos/github/open-contracting/ocdskit/badge.svg?branch=master
   :target: https://coveralls.io/github/open-contracting/ocdskit?branch=master
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/ocdskit.svg
   :target: https://pypi.org/project/ocdskit/
